#!/bin/bash
# Copyright (c) 2012 Cloudera, Inc. All rights reserved.
#
# Runs chive jar.

# Time marker for both stderr and stdout
date; date 1>&2

# debug
set -x

cloudera_config=`dirname $0`
cloudera_config=`cd "$cloudera_config/../common"; pwd`
. ${cloudera_config}/cloudera-config.sh

# attempt to find java
locate_java_home

# load the parcel environment
source_parcel_environment

if [ "4" = "$CDH_VERSION" ]; then
  . ${cloudera_config}/cdh4-default
  HDFS_BIN=$HADOOP_HDFS_HOME/bin/hdfs
else
  echo "ERROR: Unsupported version $CDH_VERSION"
  exit 1
fi

echo "using $JAVA_HOME as JAVA_HOME"
echo "using $CDH_VERSION as CDH_VERSION"
echo "using $CONF_DIR as CONF_DIR"

MAIN=com.cloudera.enterprise.chive.Main

# Create the CLASSPATH for executing chive. It needs:
# - Hive
# - Hadoop (Common + MR client, any version + HDFS client).
# - Hive and Hadoop configurations.
CLASSPATH=$(ls ${MGMT_HOME}/lib/chive-*.jar | head -n 1)
CLASSPATH="$CLASSPATH:$CONF_DIR/hadoop-conf"
CLASSPATH="$CLASSPATH:$CONF_DIR/hive-conf"
CLASSPATH="$CLASSPATH:$(hadoop classpath)"
CLASSPATH="$CLASSPATH:$CDH_HIVE_HOME/*"
CLASSPATH="$CLASSPATH:$CDH_HIVE_HOME/lib/*"

# Check if there's anything we should add to the classpath.
HIVE_ENV="$CONF_DIR/hive-conf/hive-env.sh"
if [ -f $HIVE_ENV ]; then
  . $HIVE_ENV
fi
if [ -n "$AUX_CLASSPATH" ]; then
  CLASSPATH="$CLASSPATH:$AUX_CLASSPATH"
fi

acquire_kerberos_tgt hdfs.keytab

# Disable IPv6.
JAVA_OPTS="-Djava.net.preferIPv4Stack=true $JAVA_OPTS"

exec $JAVA_HOME/bin/java $JAVA_OPTS -cp "$CLASSPATH" $MAIN \
    -s $CONF_DIR/logs/summary.json "$@"
